@@ -24,9 +24,12 @@ class Ant():
         self.record_way = [[0,0]]   #路径节点信息记录
         
 
-    def run(self,map_data,pher_data):
+    def run(self,map_data,pher_data,posi = None,dest = None):
         #Step 0:把蚂蚁放在起点处
-        self.position = [0,0]       #蚂蚁初始位置[y,x] = [0,0],考虑到列表索引的特殊性，先定y，后定x
+        if posi == None:
+            self.position = [0,0]       #蚂蚁初始位置[y,x] = [0,0],考虑到列表索引的特殊性，先定y，后定x
+        if dest == None:
+            self.destination = [len(map_data)-1,len(map_data)]
         #Step 1:不断找下一节点，直到走到终点或者力竭 
         for i in range(self.max_step):
             r = self.select_next_node(map_data,pher_data)
